<div align="center">

# DeepTAN

## A novel graph-based multi-task framework designed to infer large-scale multi-omics trait-associated networks (TANs) and reconstruct phenotype-specific omics states

[![pypi-badge](https://img.shields.io/pypi/v/deeptan)](https://pypi.org/project/deeptan)
[![pypi-badge](https://img.shields.io/pypi/dm/deeptan.svg?label=Pypi%20downloads)](https://pypi.org/project/deeptan)
![License](https://img.shields.io/github/license/cma2015/DeepTAN)

</div>
